import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="spotmax-agent",
    version="0.0.2",
    author="liuzoxan",
    author_email="liuzoxan@gmail.com",
    description="spotmax agent package",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/pypa/sampleproject",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        # '你的库依赖的第三方库（也可以指定版本）',
        # exapmle
        # 'pyautogui',
        # 'Django >= 1.11, != 1.11.1, <= 2',
    ],
)
